
# Class: WithLocation




URI: [ks:WithLocation](https://w3id.org/linkml/tests/kitchen_sink/WithLocation)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[Place]<in%20location%200..1-%20[WithLocation],[MarriageEvent]uses%20-.->[WithLocation],[Place],[MarriageEvent])](https://yuml.me/diagram/nofunky;dir:TB/class/[Place]<in%20location%200..1-%20[WithLocation],[MarriageEvent]uses%20-.->[WithLocation],[Place],[MarriageEvent])

## Mixin for

 * [MarriageEvent](MarriageEvent.md) (mixin) 

## Referenced by Class


## Attributes


### Own

 * [in location](in_location.md)  <sub>0..1</sub>
     * Range: [Place](Place.md)
